@@ -416,9 +416,11 @@ class SoftwareDeployment(signal_responder.SignalResponder):
                 yield swc_io.InputConfig(
                     name=self.DEPLOY_PROJECT_ID, value=creds['project_id'],
                     description=_('ID of project for API authentication'))
-                yield swc_io.InputConfig(
-                    name=self.DEPLOY_REGION_NAME, value=creds['region_name'],
-                    description=_('Region name for API authentication'))
+                if creds['region_name']:
+                    yield swc_io.InputConfig(
+                        name=self.DEPLOY_REGION_NAME,
+                        value=creds['region_name'],
+                        description=_('Region name for API authentication'))
             if self._signal_transport_zaqar():
                 yield swc_io.InputConfig(
                     name=self.DEPLOY_QUEUE_ID,
@@ -545,12 +547,13 @@ class SoftwareDeployment(signal_responder.SignalResponder):
 
     def get_attribute(self, key, *path):
         """Resource attributes map to deployment outputs values."""
-        sd = self.rpc_client().show_software_deployment(
-            self.context, self.resource_id)
-        ov = sd[rpc_api.SOFTWARE_DEPLOYMENT_OUTPUT_VALUES] or {}
-        if key in ov:
-            attribute = ov.get(key)
-            return attributes.select_from_attribute(attribute, path)
+        if self.resource_id is not None:
+            sd = self.rpc_client().show_software_deployment(
+                self.context, self.resource_id)
+            ov = sd[rpc_api.SOFTWARE_DEPLOYMENT_OUTPUT_VALUES] or {}
+            if key in ov:
+                attribute = ov.get(key)
+                return attributes.select_from_attribute(attribute, path)
 
         # Since there is no value for this key yet, check the output schemas
         # to find out if the key is valid
